@@ -1,28 +1,26 @@
-#!/usr/bin/env python
-# encoding: utf-8
+#!/usr/bin/env python3
 
 """
 .. codeauthor:: Tsuyoshi Hombashi <tsuyoshi.hombashi@gmail.com>
 """
 
-from __future__ import print_function, unicode_literals
-
 import pytest
+
 from allpairspy import AllPairs
 
 
-def function_to_be_tested(brand, operating_system, minute):
+def function_to_be_tested(brand: str, operating_system: str, minute: int) -> bool:
     # do something
 
     return True
 
 
-class TestParameterized(object):
+class TestParameterized:
     @pytest.mark.parametrize(
         ["brand", "operating_system", "minute"],
         [
-            value_list
-            for value_list in AllPairs(
+            values
+            for values in AllPairs(
                 [["Brand X", "Brand Y"], ["98", "NT", "2000", "XP"], [10, 15, 30, 60]]
             )
         ],
